@@ -9,7 +9,7 @@ import xarray as xr
 
 from xyzpy.manage import load_ds, load_df
 from xyzpy.gen.farming import Runner, Harvester, Sampler, label
-from xyzpy.gen.batch import grow
+from xyzpy.gen.cropping import grow
 
 
 # -------------------------------- Fixtures --------------------------------- #
@@ -184,6 +184,24 @@ class TestHarvester:
         assert h.full_ds.identical(fn3_fba_ds)
         assert hds.identical(fn3_fba_ds)
 
+    def test_label_as_harvester(self, fn3_fba_runner, fn3_fba_ds):
+        with tempfile.TemporaryDirectory() as tmpdir:
+            fl_pth = os.path.join(tmpdir, 'test.h5')
+            h = label(
+                harvester=fl_pth,
+                fn_args=('a', 'b'),
+                var_names=['sum', 'even', 'array'],
+                var_dims={'array': ['time']},
+                var_coords={'time': np.linspace(0, 1.0, 3)},
+                constants={'c': 100},
+                attrs={'fruit': 'apples'},
+            )(fn3_fba)
+            h.harvest_combos((('a', (1, 2)), ('b', (3, 4))))
+            hds = load_ds(fl_pth)
+        assert h.last_ds.identical(fn3_fba_ds)
+        assert h.full_ds.identical(fn3_fba_ds)
+        assert hds.identical(fn3_fba_ds)
+
     def test_harvest_combos_new_sow_reap_separate(self, fn3_fba_runner,
                                                   fn3_fba_ds):
         with tempfile.TemporaryDirectory() as tmpdir:
@@ -343,6 +361,46 @@ class TestHarvester:
             assert h.full_ds['sum'].chunks is not None
             h.full_ds.close()
 
+    def test_expand_dims_and_ellipsis_combos(self):
+
+        @label('x', harvester=True)
+        def foo(a, b, c=5):
+            return a + b + c
+
+        foo.harvest_combos({
+            'a': [1, 2],
+            'b': [3, 4],
+        })
+
+        assert foo.full_ds['x'].ndim == 2
+        foo.expand_dims('c', 5)
+        assert foo.full_ds['x'].ndim == 3
+
+        foo.harvest_combos({
+            'a': ...,
+            'b': ...,
+            'c': [8, 9],
+        })
+        assert list(foo.full_ds['c'].values) == [5, 8, 9]
+
+    def test_drop_sel(self):
+        @label('x', harvester=True)
+        def foo(a, b, c):
+            return a + b + c
+
+        foo.harvest_combos({
+            'a': [1, 2],
+            'b': [3, 4],
+            'c': [5, 6, 7],
+        })
+
+        assert foo.full_ds['x'].ndim == 3
+        assert foo.full_ds['x'].size == 12
+        foo.drop_sel(c=6)
+        assert foo.full_ds['x'].ndim == 3
+        assert foo.full_ds['x'].size == 8
+        assert 6 not in foo.full_ds.coords['c'].values
+
 
 class TestSampler:
 
@@ -369,8 +427,8 @@ class TestSampler:
             hdf = load_df(fl_pth, engine=engine)
 
             assert len(hdf) == 10
-            assert s.last_df.equals(hdf)
-            assert s.full_df.equals(hdf)
+            assert s.last_df.compare(hdf).empty
+            assert s.full_df.compare(hdf).empty
 
             s.sample_combos(20, combos)
             hdf = load_df(fl_pth, engine=engine)
@@ -405,5 +463,5 @@ class TestSampler:
             c.reap()
             hdf = load_df(fl_pth)
             assert len(hdf) == 10
-            assert s.last_df.equals(hdf)
-            assert s.full_df.equals(hdf)
+            assert s.last_df.compare(hdf).empty
+            assert s.full_df.compare(hdf).empty
