@@ -3,7 +3,6 @@
 import functools
 import operator
 import itertools
-import warnings
 import time
 import math
 import sys
@@ -17,23 +16,6 @@ def isiterable(obj):
     return isinstance(obj, Iterable)
 
 
-def _choose_executor_depr_pool(executor, pool):
-    # XXX: remove this eventually
-    if pool is not None:
-
-        if executor is None:
-            msg = ("The 'pool' keyword is deprecated in "
-                   "favour of the more explicit 'executor'.")
-            warnings.warn(msg, FutureWarning)
-            return pool
-
-        else:
-            raise ValueError("Can't specify the deprecated 'pool' "
-                             "option as well as 'executor'")
-
-    return executor
-
-
 def prod(it):
     """Product of an iterable.
     """
